# -*- coding: utf-8 -*-
# Copyright (C)2007 Ingeniweb

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING. If not, write to the
# Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
""" defines a test class and its Plone Site layer for plone tests
"""
from Products.PloneTestCase import PloneTestCase as ptc
from Products.PloneTestCase.layer import onsetup

from Products.Five import zcml
from Products.Five import fiveconfigure

@onsetup
def setup_reject_anonymous_site():
    """
    """
    import iw.rejectanonymous
    fiveconfigure.debug_mode = True
    zcml.load_config('configure.zcml', iw.rejectanonymous)
    fiveconfigure.debug_mode = False

setup_reject_anonymous_site()
ptc.setupPloneSite()

class TestCase(ptc.FunctionalTestCase):
    """test case used in tests"""



# -*- coding: utf-8 -*-
# Copyright (C)2007 Ingeniweb

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING. If not, write to the
# Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""rejectanonymous initialization"""
from zope.interface import Interface
from AccessControl import getSecurityManager

class IPrivateSite(Interface):
    """Marker for sites requiring login"""

from zExceptions import Unauthorized

valid_ids = set(('login_form', 'require_login', 'login.js', 'spinner.gif',
                 'mail_password_form', 'mail_password', 'contact-info',
                 'pwreset_form', 'pwreset_finish'))

valid_subparts = set(('portal_css', 'portal_javascripts', 'passwordreset'))

def isAnonymousUser():
    u = getSecurityManager().getUser()
    return (u is None or u.getUserName() == 'Anonymous User')

def getPortalLogoId(portal):
    props = portal['base_properties']
    return props.getProperty('logoName')

def rejectAnonymous(portal, request):

    if isAnonymousUser():
        url = request.physicalPathFromURL(request['URL'])
        if url[-1] == 'index_html':
            url.pop()
        item_id = url[-1]
        logo_id = getPortalLogoId(portal)

        if url and not (item_id in valid_ids
                        or item_id == logo_id
                        or [path for path in url
                            if path in valid_subparts]):
            raise Unauthorized, "Anonymous rejected"

def insertRejectAnonymousHook(portal, event):
    """ """
    event.request.post_traverse(rejectAnonymous, (portal, event.request))

## try:
##     import plone.add.controlpanel
## except ImportError:
##     pass
## else:
import iw.rejectanonymous.plonecontrolpanel




import os
from setuptools import setup, find_packages

version = '1.0.1'

README = os.path.join(os.path.dirname(__file__),
                      'iw', 'rejectanonymous', 'docs', 'README.txt')
long_description = open(README, 'r').read() + '\n\n'

setup(name='iw.rejectanonymous',
      version=version,
      description="Disallow access to a folder and its children if user is anonymous",
      long_description=long_description,
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Framework :: Plone",
        "Framework :: Zope2",
        "Framework :: Zope3",
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        ],
      keywords='',
      author='Ingeniweb',
      author_email='support@ingeniweb.com',
      url='https://svn.plone.org/svn/collective/iw.rejectanonymous',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['iw'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          # -*- Extra requirements: -*-
      ],
      entry_points="""
      # -*- Entry points: -*-
      """,
      )



# -*- coding: utf-8 -*-
## Copyright (C) 2008 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""Patch plone "security" control panel to add a new option
"""
from zope.interface import (
    implementedBy, classImplementsOnly, alsoProvides, noLongerProvides
    )
from zope.schema import Bool
from zope.component import getGlobalSiteManager
from zope.formlib.form import FormFields
from plone.app.controlpanel import security
from iw.rejectanonymous import IPrivateSite

class IPrivateSiteSchema(security.ISecuritySchema):
    private_site = Bool(
        title=u'Private site',
        description=u"Users must login to view the site. Anonymous users are presented the login form",
        default=False,
        required=False,
        )

# add accessors to adapter
def get_private_site(self):
    return IPrivateSite.providedBy(self.portal)

security.SecurityControlPanelAdapter.get_private_site = get_private_site

def set_private_site(self, value):
    operator = value and alsoProvides or noLongerProvides
    operator(self.portal, IPrivateSite)

security.SecurityControlPanelAdapter.set_private_site = set_private_site

security.SecurityControlPanelAdapter.private_site = property(
    security.SecurityControlPanelAdapter.get_private_site,
    security.SecurityControlPanelAdapter.set_private_site
    )

# re-register adapter with new interface
_decl = implementedBy(security.SecurityControlPanelAdapter)
_decl -= security.ISecuritySchema
_decl += IPrivateSiteSchema
classImplementsOnly(security.SecurityControlPanelAdapter, _decl.interfaces())
del _decl

getGlobalSiteManager().registerAdapter(security.SecurityControlPanelAdapter)

# re-instanciate form
security.SecurityControlPanel.form_fields = FormFields(
    IPrivateSiteSchema
    )
